# OpenFisca-US

[![codecov](https://codecov.io/gh/PolicyEngine/openfisca-us/branch/master/graph/badge.svg?token=BLoCjCf5Qr)](https://codecov.io/gh/PolicyEngine/openfisca-us)

This is a project in its early stages to explore a working prototype of the US tax and benefit system modeled with the OpenFisca simulation framework.

To install, run `pip install git+https://github.com/policyengine/openfisca-us`.

To contribute, please see the [wiki](https://github.com/PolicyEngine/openfisca-us/wiki).
